@@ -50,7 +50,7 @@ import pyflakes.messages
 import pyflakes.reporter
 
 
-__version__ = "2.2.0"
+__version__ = "2.2.1"
 
 
 _LOGGER = logging.getLogger("autoflake")
@@ -1574,7 +1574,7 @@ def _main(
     return exit_status
 
 
-def main():
+def main() -> int:
     """Command-line entry point."""
     try:
         # Exit on broken pipe.
